pub struct BitcoinCore;Trait Implementations
Sourceimpl ProjectCommands for BitcoinCore
impl ProjectCommands for BitcoinCore
Sourcefn build_command(&self) -> String
fn build_command(&self) -> String
Full clean build, run once before analyzing a folder when the user did
not supply an explicit
--command.Sourcefn test_command(&self, target_file_path: &str, jobs: u32) -> Result<String>
fn test_command(&self, target_file_path: &str, jobs: u32) -> Result<String>
Incremental-build-and-test command for the mutated
target_file_path.
jobs is the parallelism passed to the compiler (0 = system default).Sourcefn build_timeout_secs(&self) -> u64
fn build_timeout_secs(&self) -> u64
Timeout, in seconds, allowed for
ProjectCommands::build_command.Auto Trait Implementations
impl Freeze for BitcoinCore
impl RefUnwindSafe for BitcoinCore
impl Send for BitcoinCore
impl Sync for BitcoinCore
impl Unpin for BitcoinCore
impl UnsafeUnpin for BitcoinCore
impl UnwindSafe for BitcoinCore