pub struct Secp256k1;Trait Implementations
Sourceimpl ProjectCommands for Secp256k1
impl ProjectCommands for Secp256k1
Sourcefn build_command(&self) -> String
fn build_command(&self) -> String
Full clean build, run once before analyzing a folder when the user did
not supply an explicit
--command.Sourcefn test_command(&self, _target_file_path: &str, jobs: u32) -> Result<String>
fn test_command(&self, _target_file_path: &str, jobs: u32) -> Result<String>
Incremental-build-and-test command for the mutated
target_file_path.
jobs is the parallelism passed to the compiler (0 = system default).Sourcefn build_timeout_secs(&self) -> u64
fn build_timeout_secs(&self) -> u64
Timeout, in seconds, allowed for
ProjectCommands::build_command.Auto Trait Implementations
impl Freeze for Secp256k1
impl RefUnwindSafe for Secp256k1
impl Send for Secp256k1
impl Sync for Secp256k1
impl Unpin for Secp256k1
impl UnsafeUnpin for Secp256k1
impl UnwindSafe for Secp256k1