ProjectCommands

Trait ProjectCommands 

pub trait ProjectCommands {
    // Required methods
    fn build_command(&self) -> String;
    fn test_command(&self, target_file_path: &str, jobs: u32) -> Result<String>;

    // Provided method
    fn build_timeout_secs(&self) -> u64 { ... }
}
Build and test commands for a single project.

Required Methods

fn build_command(&self) -> String

Full clean build, run once before analyzing a folder when the user did not supply an explicit --command.

fn test_command(&self, target_file_path: &str, jobs: u32) -> Result<String>

Incremental-build-and-test command for the mutated target_file_path. jobs is the parallelism passed to the compiler (0 = system default).

Provided Methods

fn build_timeout_secs(&self) -> u64

Timeout, in seconds, allowed for ProjectCommands::build_command.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors