AridNodeDetector

Struct AridNodeDetector 

pub struct AridNodeDetector { /* private fields */ }
Arid node detector implementing Google’s algorithm

Implementations

Source

impl AridNodeDetector

pub fn new() -> Result<Self>

pub fn is_arid(&mut self, node: &AstNode) -> bool

Implementation of Google’s arid node detection algorithm arid(N) = expert(N) if simple(N) = 1 if ∀(arid(c)) = 1, ∀c ∈ N otherwise

pub fn should_mutate_line( &mut self, line_content: &str, line_number: usize, ) -> bool

Check if a line should be mutated based on AST analysis

pub fn add_expert_rule( &mut self, pattern: &str, description: &str, ) -> Result<()>

Add a new expert rule at runtime

pub fn get_stats(&self) -> HashMap<String, usize>

Get statistics about arid node detection

pub fn analyze_file_detailed(&mut self, file_content: &str) -> DetailedAnalysis

Export detailed analysis of which lines were filtered and why

pub fn clear_cache(&mut self)

Clear the cache (useful for testing or when rules change)