Structs
- Database
- Mutant
Data - Data collected during mutation for a single generated mutant.
- Mutant
Row - A mutant row read back from the database.
Functions
- compute_
patch_ hash - Compute the SHA-256 hex digest of
diff. - generate_
diff - Generate a proper unified diff by running
git diff --no-indexbetween the original file on disk and a temp file containingmutated_content. The resulting patch includes context lines and is suitable forgit apply.